@@ -1,7 +1,6 @@
-#' Shapley Population Variable Importance Measure (SPVIM) estimates
+#' Shapley Population Variable Importance Measure (SPVIM) Estimates and Inference
 #'
-#' Compute estimates and confidence intervals for the
-#' SPVIMs, using cross-validation.
+#' Compute estimates and confidence intervals for the SPVIMs, using cross-fitting.
 #' This essentially involves splitting the data into V train/test splits; train the learners on the training data, evaluate importance on the test data; and average over these splits.
 #'
 #' @param Y the outcome.
@@ -10,15 +9,26 @@
 #' @param weights weights for the computed influence curve (e.g., inverse probability weights for coarsened-at-random settings)
 #' @param type the type of parameter (e.g., R-squared-based is \code{"r_squared"}).
 #' @param SL.library a character vector of learners to pass to \code{SuperLearner}, if \code{f1} and \code{f2} are Y and X, respectively. Defaults to \code{SL.glmnet}, \code{SL.xgboost}, and \code{SL.mean}.
+#' @param univariate_SL.library (optional) a character vector of learners to pass to \code{SuperLearner} for estimating univariate regression functions. Defaults to \code{SL.polymars}
 #' @param gamma the fraction of the sample size to use when sampling subsets (e.g., \code{gamma = 1} samples the same number of subsets as the sample size)
 #' @param alpha the level to compute the confidence interval at. Defaults to 0.05, corresponding to a 95\% confidence interval.
 #' @param delta the value of the \eqn{\delta}-null (i.e., testing if importance < \eqn{\delta}); defaults to 0.
 #' @param na.rm should we remove NA's in the outcome and fitted values in computation? (defaults to \code{FALSE})
+#' @param stratified should the generated folds be stratified based on the outcome (helps to ensure class balance across cross-validation folds)?
 #' @param ... other arguments to the estimation tool, see "See also".
 #'
 #' @return An object of class \code{vim}. See Details for more information.
 #'
-#' @details See the paper by Williamson and Feng (2020) for more
+#' @details We define the SPVIM as the weighted average of the population difference in 
+#' predictiveness over all subsets of features not containing feature \eqn{j}.
+#' 
+#' This is equivalent to finding the solution to a population weighted least squares problem. This 
+#' key fact allows us to estimate the SPVIM using weighted least squares, where we first 
+#' sample subsets from the power set of all possible features using the Shapley sampling distribution; then
+#' use cross-fitting to obtain estimators of the predictiveness of each sampled subset; and finally, solve the 
+#' least squares problem given in Williamson and Feng (2020).
+#' 
+#' See the paper by Williamson and Feng (2020) for more
 #' details on the mathematics behind this function, and the validity
 #' of the confidence intervals.
 #' The function works by estimating
@@ -43,10 +53,8 @@
 #' }
 #'
 #' @examples
-#' \donttest{
-#' ## don't test because this can take some time to run
 #' library(SuperLearner)
-#' library(gam)
+#' library(ranger)
 #' n <- 100
 #' p <- 2
 #' ## generate the data
@@ -59,18 +67,24 @@
 #' y <- as.matrix(smooth + stats::rnorm(n, 0, 1))
 #'
 #' ## set up a library for SuperLearner
-#' learners <- c("SL.mean", "SL.gam")
+#' learners <- c("SL.mean", "SL.ranger")
 #'
 #' ## -----------------------------------------
-#' ## using Super Learner
+#' ## using Super Learner (with a small number of CV folds,
+#' ## for illustration only)
 #' ## -----------------------------------------
 #' set.seed(4747)
-#' est <- sp_vim(Y = y, X = x, V = 5, type = "r_squared", SL.library = learners, alpha = 0.05)
-#' }
+#' est <- sp_vim(Y = y, X = x, V = 2, type = "r_squared", 
+#' SL.library = learners, alpha = 0.05)
+#' 
 #' @seealso \code{\link[SuperLearner]{SuperLearner}} for specific usage of the \code{SuperLearner} function and package.
 #' @importFrom stats pnorm
 #' @export
-sp_vim <- function(Y, X, V = 5, weights = rep(1, length(Y)), type = "r_squared", SL.library = c("SL.glmnet", "SL.xgboost", "SL.mean"), gamma = 1, alpha = 0.05, delta = 0, na.rm = FALSE, ...) {
+sp_vim <- function(Y, X, V = 5, weights = rep(1, length(Y)), type = "r_squared", 
+                   SL.library = c("SL.glmnet", "SL.xgboost", "SL.mean"), 
+                   univariate_SL.library = NULL,
+                   gamma = 1, alpha = 0.05, delta = 0, na.rm = FALSE,
+                   stratified = FALSE, ...) {
     ## check to see if f1 and f2 are missing
     ## if the data is missing, stop and throw an error
     if (missing(Y)) stop("You must enter an outcome, Y.")
@@ -85,11 +99,9 @@ sp_vim <- function(Y, X, V = 5, weights = rep(1, length(Y)), type = "r_squared",
     if (is.na(full_type)) stop("We currently do not support the entered variable importance parameter.")
 
     ## set up the cross-validation
-    outer_folds <- sample(1:2, dim(Y)[1], replace = TRUE, prob = c(0.25, 0.75))
-    inner_folds_1 <- rep_len(seq_len(V), dim(Y[outer_folds == 1, , drop = FALSE])[1])
-    inner_folds_1 <- sample(inner_folds_1)
-    inner_folds_2 <- rep_len(seq_len(V), dim(Y[outer_folds == 2, , drop = FALSE])[1])
-    inner_folds_2 <- sample(inner_folds_2)
+    outer_folds <- .make_folds(Y, V = 2, stratified = stratified, probs = c(0.25, 0.75))
+    inner_folds_1 <- .make_folds(Y[outer_folds == 1, , drop = FALSE], V = V, stratified = stratified)
+    inner_folds_2 <- .make_folds(Y[outer_folds == 2, , drop = FALSE], V = V, stratified = stratified)
 
     ## sample subsets, set up Z
     z_w_lst <- sample_subsets(p = dim(X)[2], n = dim(X)[1], gamma = gamma)
@@ -107,7 +119,7 @@ sp_vim <- function(Y, X, V = 5, weights = rep(1, length(Y)), type = "r_squared",
     ic_none <- cv_predictiveness_update(preds_none, Y[outer_folds == 2, , drop = FALSE], inner_folds_2, weights[outer_folds == 2], type = full_type, na.rm = na.rm)$ic
 
     ## get v, preds, ic for remaining non-null groups in S
-    preds_lst <- lapply(S[-1], function(s) run_sl(Y[outer_folds == 2, , drop = FALSE], X[outer_folds == 2, ], V = V, SL.library = SL.library, s = s, folds = inner_folds_2, ...))
+    preds_lst <- lapply(S[-1], function(s) run_sl(Y[outer_folds == 2, , drop = FALSE], X[outer_folds == 2, ], V = V, SL.library = SL.library, univariate_SL.library = univariate_SL.library, s = s, folds = inner_folds_2, ...))
     v_lst <- lapply(preds_lst, function(x) cv_predictiveness_point_est(fitted_values = x$preds, y = Y[outer_folds == 2, , drop = FALSE], folds = x$folds, weights = weights[outer_folds == 2], type = full_type, na.rm = na.rm)$point_est)
     ic_lst <- lapply(preds_lst, function(x) cv_predictiveness_update(fitted_values = x$preds, y = Y[outer_folds == 2, , drop = FALSE], folds = x$folds, weights = weights[outer_folds == 2], type = full_type, na.rm = na.rm)$ic)
     v <- matrix(c(v_none, unlist(v_lst)))
@@ -122,9 +134,9 @@ sp_vim <- function(Y, X, V = 5, weights = rep(1, length(Y)), type = "r_squared",
     kkt_matrix_22 <- matrix(0, nrow = dim(kkt_matrix_21)[1],  ncol = dim(kkt_matrix_12)[2])
     kkt_matrix <- rbind(cbind(kkt_matrix_11, kkt_matrix_12), cbind(kkt_matrix_21, kkt_matrix_22))
     ls_matrix <- rbind(2 * t(A_W) %*% v_W, c_n)
-    ls_solution <- solve(kkt_matrix) %*% ls_matrix
-    est <- ls_solution[1:(ncol(X) + 1), ]
-    lambdas <- ls_solution[(ncol(X) + 2):dim(ls_solution)[1], ]
+    ls_solution <- MASS::ginv(kkt_matrix) %*% ls_matrix
+    est <- ls_solution[1:(ncol(X) + 1), , drop = FALSE]
+    lambdas <- ls_solution[(ncol(X) + 2):dim(ls_solution)[1], , drop = FALSE]
 
     ## compute the SPVIM ICs
     ic_mat <- do.call(rbind, c(list(ic_none), ic_lst))
