@@ -1,4 +1,4 @@
-#' Nonparametric Variable Importance Estimates
+#' Nonparametric Variable Importance Estimates and Inference
 #'
 #' Compute estimates of and confidence intervals for nonparametric risk-based variable importance.
 #'
@@ -21,7 +21,16 @@
 #'
 #' @return An object of classes \code{vim} and the type of risk-based measure. See Details for more information.
 #'
-#' @details In the interest of transparency, we return most of the calculations
+#' @details We define the population variable importance measure (VIM) for the group 
+#' of features (or single feature) \eqn{s} with respect to the predictiveness measure
+#' \eqn{V} by \deqn{\psi_{0,s} := V(f_0, P_0) - V(f_{0,s}, P_0),} where \eqn{f_0} is 
+#' the population predictiveness maximizing function, \eqn{f_{0,s}} is the population
+#' predictiveness maximizing function that is only allowed to access the features with
+#' index not in \eqn{s}, and \eqn{P_0} is the true data-generating distribution. VIM estimates are
+#' obtained by obtaining estimators \eqn{f_n} and \eqn{f_{n,s}} of \eqn{f_0} and \eqn{f_{0,s}},
+#' respectively; obtaining an estimator \eqn{P_n} of \eqn{P_0}; and finally, setting \eqn{\psi_{n,s} := V(f_n, P_n) - V(f_{n,s}, P_n)}.
+#' 
+#' In the interest of transparency, we return most of the calculations
 #' within the \code{vim} object. This results in a list containing:
 #' \itemize{
 #'  \item{call}{ - the call to \code{vim}}
@@ -112,22 +121,6 @@ vim <- function(Y, X, f1 = NULL, f2 = NULL, indx = 1, weights = rep(1, length(Y)
 
     ## if run_regression = TRUE, then fit SuperLearner
     if (run_regression) {
-        ## create folds for cross-fitting
-        .make_folds <- function(y, V, stratified = FALSE) {
-            folds <- vector("numeric", length(y))
-            if (stratified) {
-                folds_1 <- rep(seq_len(V), length = sum(y == 1))
-                folds_0 <- rep(seq_len(V), length = sum(y == 0))
-                folds_1 <- sample(folds_1)
-                folds_0 <- sample(folds_0)
-                folds[y == 1] <- folds_1
-                folds[y == 0] <- folds_0
-            } else {
-                folds <- rep(seq_len(V), length = length(y))
-                folds <- sample(folds)
-            }
-            return(folds)
-        }
         if (is.null(folds)) {
             folds <- .make_folds(Y, V = 2, stratified = stratified)
         }
