@@ -7,7 +7,7 @@ library("xgboost")
 ## generate the data
 set.seed(4747)
 p <- 2
-n <- 10000
+n <- 5000
 x <- data.frame(replicate(p, stats::runif(n, -5, 5)))
 ## apply the function to the x's
 y <- (x[,1]/5)^2*(x[,1]+7)/5 + (x[,2]/3)^2 + rnorm(n, 0, 1)
@@ -25,13 +25,17 @@ shapley_val_2 <- (1/2) * (r2_two - 0) + (1/2) * (r2_full - r2_one)
 
 ## set up a library for SuperLearner
 SL.xgboost1 <- function(..., max_depth = 1, ntree = 500, shrinkage = 0.1){
-  SL.xgboost(..., max_depth = max_depth, ntree = ntree, shrinkage = shrinkage)
+  SL.xgboost(..., objective = 'reg:squarederror', max_depth = max_depth, ntree = ntree, shrinkage = shrinkage)
 }
-learners <- c("SL.glm.interaction", "SL.xgboost1", "SL.mean")
+learners <- c("SL.glm.interaction", "SL.xgboost1", "SL.glmnet", "SL.mean")
+univariate_learners <- "SL.polymars"
 V <- 2
 
 test_that("Estimating SPVIMs works", {
-  est <- sp_vim(Y = y, X = x, V = V, type = "r_squared", SL.library = learners, gamma = 1, alpha = 0.05, delta = 0, cvControl = list(V = V), env = environment())
+  expect_warning(est <- sp_vim(Y = y, X = x, V = V, type = "r_squared", 
+                               SL.library = learners, 
+                gamma = .1, alpha = 0.05, delta = 0, 
+                cvControl = list(V = V), env = environment()))
   ## check that the estimate is approximately correct
   expect_equal(as.numeric(est$est[2]), shapley_val_1, tolerance = 0.2)
   ## check that the SE, CI work
@@ -44,6 +48,14 @@ test_that("Estimating SPVIMs works", {
   expect_silent(format(est)[1])
   expect_output(print(est), "Estimate", fixed = TRUE)
 })
+test_that("Estimating SPVIMs with special univariate library works", {
+  est <- sp_vim(Y = y, X = x, V = V, type = "r_squared", 
+                SL.library = learners, univariate_SL.library = univariate_learners,
+                gamma = .1, alpha = 0.05, delta = 0, 
+                cvControl = list(V = V), env = environment())
+  ## check that the estimate is approximately correct
+  expect_equal(as.numeric(est$est[2]), shapley_val_1, tolerance = 0.2)
+})
 
 
 test_that("Error messages work", {
